@@ -2,12 +2,11 @@ package Growl::Tiny;
 use strict;
 use warnings;
 
+our $VERSION = '0.0.3'; # VERSION
+
 use base 'Exporter';
 our @EXPORT_OK = ( 'notify' );
 
-our $VERSION = '0.0.2';
-
-
 my $GROWL_COMMAND = "/usr/local/bin/growlnotify";
 
 #_* Libraries
@@ -23,7 +22,7 @@ Growl::Tiny - tiny perl module for sending Growl notifications on Mac OS X
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 SYNOPSIS
 
@@ -168,6 +167,10 @@ sub notify {
         push @command_line_args, ( '-t', $options->{title} );
     }
 
+    if ( $options->{identifier} ) {
+        push @command_line_args, ( '-d', $options->{identifier} );
+    }
+
     #print "COMMAND: ", join " ", @command_line_args, "\n";
     return system( @command_line_args ) ? 0 : 1;
 }
